import functools
from flask import request

def authenticate(klass):
    def decorator(funct):
        @functools.wraps(funct)
        def wrapper(*args, **kwargs):
            token = request.headers.get('auth-token')
            # ensure that the token is valid
            # extract the user id from the token
            user_id = ""
            return funct(user_id, *args, **kwargs)
        return wrapper
    return decorator


import functools
from flask import make_response, request
import json


def serialize(obj):
    '''Used to convert a class to json'''
    return obj.__dict__

def toJSONResponse(object):
    '''Convert an object to json response'''
    data = object.__dict__
    response = make_response(json.dumps(data, default = serialize))
    response.headers['Content-Type'] = 'application/json'
    ##print(json.dumps(data, default = serialize))
    return response

def deserialise(klass):
    def decorator(funct):
        @functools.wraps(funct)
        def wrapper(*args, **kwargs):
            body = request.json
            deserialise_body = klass(body)
            return funct(deserialise_body, *args, **kwargs)
        return wrapper
    return decorator

def serialise():
    def decorator(funct):
        @functools.wraps(funct)
        def wrapper(*args, **kwargs):
            return toJSONResponse(funct(*args, **kwargs))
        return wrapper
    return decorator


from functools import wraps
import json

def parse(file_name, path):
    path = path.split(".")
    def decorator(klass):
        old_init = klass.__init__
        @wraps(klass.__init__)
        def decorated_init(self):
            with open(file_name, "r") as inputFile:
                config_data = json.loads(inputFile.read())
                for x in path:
                    config_data = config_data[x]
                old_init(self,**config_data)
        klass.__init__ = decorated_init
        return klass
    return decorator